@@ -138,7 +138,20 @@ class TestScraperNational:
                 ],
                 ["AFG", "96.99", "3.41", "96.99", "3.41"],
             ]
-            assert runner.get_sources() == sources
+            combined_sources = [
+                (
+                    "#date+start+conflict",
+                    "2022-02-24",
+                    "Meduza",
+                    "https://meduza.io/en/news/2022/02/24/putin-announces-start-of-military-operation-in-eastern-ukraine",
+                ),
+            ] + sources
+            assert (
+                runner.get_sources(
+                    additional_sources=configuration["additional_sources"]
+                )
+                == combined_sources
+            )
             runner.set_not_run_many(names)
 
             name = "access"
@@ -304,7 +317,7 @@ class TestScraperNational:
             ]
             run_check_scraper(name, runner, level, headers, values, sources)
 
-            runner = Runner(("UKN",), adminone, downloader, dict(), today)
+            runner = Runner(("UKR",), adminone, downloader, dict(), today)
             runner.add_configurables(scraper_configuration, level)
 
             name = "casualties"
@@ -312,7 +325,7 @@ class TestScraperNational:
                 ["CiviliansKilled", "CiviliansInjured"],
                 ["#affected+killed", "#affected+injured"],
             )
-            values = [{"UKN": "351"}, {"UKN": "707"}]
+            values = [{"UKR": "351"}, {"UKR": "707"}]
             sources = [
                 (
                     "#affected+killed",
